abacusai.forecasting_analysis_graph_data — AbacusAI documentation

# abacusai.forecasting_analysis_graph_data

## Classes

`EdaChartDescription` | Eda Chart Description.
`ItemStatistics` | ItemStatistics representation.
`AbstractApiClass` |
`ForecastingAnalysisGraphData` | Forecasting Analysis Graph Data representation.

## Module Contents

class abacusai.forecasting_analysis_graph_data.EdaChartDescription(client, chartType=None, description=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Chart Description.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chartType (str) – Name of chart.

    - description (str) – Description of the eda chart.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.forecasting_analysis_graph_data.ItemStatistics(client, missingPercent=None, count=None, median=None, mean=None, p10=None, p90=None, stddev=None, min=None, max=None, lowerBound=None, upperBound=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  ItemStatistics representation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - missingPercent (float) – percentage of missing values in data

    - count (int) – count of data

    - median (float) – median of the data

    - mean (float) – mean value of the data

    - p10 (float) – 10th percentile of the data

    - p90 (float) – 90th_percentile of the data

    - stddev (float) – standard deviation of the data

    - min (int) – min value in the data

    - max (int) – max value in the data

    - lowerBound (float) – lower bound threshold of the data

    - upperBound (float) – upper bound threshold of the data

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.forecasting_analysis_graph_data.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.forecasting_analysis_graph_data.ForecastingAnalysisGraphData(client, data=None, xAxis=None, yAxis=None, dataColumns=None, chartName=None, chartTypes=None, itemStatistics={}, chartDescriptions={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Forecasting Analysis Graph Data representation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (list) – List of graph data

    - xAxis (str) – Feature that represents the x axis

    - yAxis (str) – Feature that represents the y axis

    - dataColumns (list) – Ordered name of the column for each rowwise data

    - chartName (str) – Name of the chart represented by the data

    - chartTypes (list) – Type of charts in that can exist in the current data.

    - itemStatistics (ItemStatistics) – In item wise charts, gives the mean, median, count, missing_percent, p10, p90, standard_deviation, min, max

    - chartDescriptions (EdaChartDescription) – List of descriptions of what the chart contains

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict